@@ -2,8 +2,11 @@
 //! Additional helping primitives
 //!
 
+mod history;
 mod methods;
+
 use crate::core::{Candle, ValueType};
+pub use history::{Buffered, Peekable, WithHistory, WithLastValue};
 pub use methods::{MAInstance, MA};
 
 /// sign is like [`f64::signum`]
@@ -32,7 +35,7 @@ pub fn sign(value: ValueType) -> ValueType {
 	// } else {
 	// 	0.
 	// }
-	((value > 0.) as i8 - (value < 0.) as i8) as ValueType
+	signi(value) as ValueType
 }
 
 /// signi is like [`f64::signum`], except 2 things
