@@ -1,5 +1,6 @@
 use crate::core::Method;
 use crate::core::{Error, PeriodType, ValueType, Window};
+use crate::helpers::Peekable;
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -118,6 +119,12 @@ impl Default for Integral {
 	}
 }
 
+impl Peekable<<Self as Method>::Output> for Integral {
+	fn peek(&self) -> <Self as Method>::Output {
+		self.value
+	}
+}
+
 #[cfg(test)]
 mod tests {
 	use super::{Integral as TestingMethod, Method};
