@@ -1,5 +1,6 @@
 use crate::core::Method;
 use crate::core::{Error, PeriodType, ValueType, Window};
+use crate::helpers::Peekable;
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -82,6 +83,12 @@ impl Method for LinearVolatility {
 	}
 }
 
+impl Peekable<<Self as Method>::Output> for LinearVolatility {
+	fn peek(&self) -> <Self as Method>::Output {
+		self.volatility
+	}
+}
+
 #[cfg(test)]
 mod tests {
 	use super::{LinearVolatility as TestingMethod, Method};
