@@ -1,5 +1,6 @@
 use crate::core::Method;
 use crate::core::{Error, PeriodType, ValueType, Window};
+use crate::helpers::Peekable;
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -79,6 +80,12 @@ impl Method for VWMA {
 	}
 }
 
+impl Peekable<<Self as Method>::Output> for VWMA {
+	fn peek(&self) -> <Self as Method>::Output {
+		self.sum / self.vol_sum
+	}
+}
+
 #[cfg(test)]
 #[allow(clippy::suboptimal_flops)]
 mod tests {
